@@ -9,6 +9,9 @@ Usage:
   igloo (-h | --help)
   igloo --version
 
+Creates a pastebin from files or standard input and returns the pastebin's URL.
+You must have a pastebin.com account to use igloo.
+
 Examples:
   igloo my_file.txt
   igloo -t 'code snippet' -s python -p private < my_code.py
@@ -33,13 +36,13 @@ Options:
 
 """
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 
 from getpass import getpass
 from json import dump, load
 from os import remove
-from os.path import abspath
+from os.path import abspath, dirname, join
 from sys import stdin
 
 try:
@@ -58,20 +61,22 @@ class PasteError(Exception):
 
 class Client(object):
 
-  key_storage_path = 'key.json'
-
   _key = None
+  _path = 'igloo_key.json'
 
   def __init__(self):
     self.session = Session()
 
   @property
   def key(self):
+    path = abspath(join(dirname(__file__), self._path))
     if self._key is None:
       try:
-        with open(self.key_storage_path) as f:
+        with open(path) as f:
           key = load(f)
       except IOError:
+        print 'Generating new credentials:'
+        print 'Cf. http://pastebin.com/api to find the required keys.'
         try:
           api_dev_key = raw_input('API dev key: ')
           req = self.session.post(
@@ -91,11 +96,11 @@ class Client(object):
             'api_dev_key': api_dev_key,
             'api_user_key': req.content,
           }
-          with open(self.key_storage_path, 'w') as g:
+          with open(path, 'w') as g:
             dump(key, g)
           print (
             'Pastebin credentials stored in %r.' %
-            (abspath(self.key_storage_path), )
+            (abspath(path), )
           )
       self._key = key
     return self._key
@@ -140,14 +145,15 @@ class Client(object):
     if syntax:
       data['api_paste_format'] = syntax
     url = self._get_response(data)
-    print 'Pastebin created! Url: %s' % (url, )
+    print 'Pastebin created! Url:\n%s' % (url, )
 
   def view_list_of_pastes(self):
     print self._get_response({'api_option': 'list'})
 
   def reset_credentials(self):
+    path = abspath(join(dirname(__file__), self._path))
     try:
-      remove(self.key_storage_path)
+      remove(path)
     except OSError:
       print 'No credentials to delete.'
     else:
